@@ -1,4 +1,4 @@
-/**
+ /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,18 +18,20 @@
 
 package org.apache.commons.crypto.jna;
 
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
+
 import org.apache.commons.crypto.cipher.AbstractCipherTest;
-import org.junit.Assume;
+import org.apache.commons.crypto.utils.AES;
 
 public class OpenSslJnaCipherTest extends AbstractCipherTest {
 
     @Override
     public void init() {
-        Assume.assumeTrue(OpenSslJna.isEnabled());
+        assumeTrue(OpenSslJna.isEnabled());
         transformations = new String[] {
-                "AES/CBC/NoPadding",
-                "AES/CBC/PKCS5Padding",
-                "AES/CTR/NoPadding"
+                AES.CBC_NO_PADDING,
+                AES.CBC_PKCS5_PADDING,
+                AES.CTR_NO_PADDING
                 };
         cipherClass = OpenSslJnaCipher.class.getName();
     }
